EXPORTS
	??0CShowInfo@@QAE@PAV0@@Z @ 1 NONAME ; CShowInfo::CShowInfo(class CShowInfo *)
	??1CFeedInfo@@UAE@XZ @ 2 NONAME ; CFeedInfo::~CFeedInfo(void)
	??1CImageHandler@@UAE@XZ @ 3 NONAME ; CImageHandler::~CImageHandler(void)
	??1CPodcastModel@@UAE@XZ @ 4 NONAME ; CPodcastModel::~CPodcastModel(void)
	??1CShowEngine@@UAE@XZ @ 5 NONAME ; CShowEngine::~CShowEngine(void)
	??1CShowInfo@@UAE@XZ @ 6 NONAME ; CShowInfo::~CShowInfo(void)
	?ActiveClientUid@CFeedEngine@@QAEIXZ @ 7 NONAME ; unsigned int CFeedEngine::ActiveClientUid(void)
	?ActiveFeedInfo@CPodcastModel@@QAEPAVCFeedInfo@@XZ @ 8 NONAME ; class CFeedInfo * CPodcastModel::ActiveFeedInfo(void)
	?ActiveShowList@CPodcastModel@@QAEAAV?$RPointerArray@VCShowInfo@@@@XZ @ 9 NONAME ; class RPointerArray<class CShowInfo> & CPodcastModel::ActiveShowList(void)
	?AddDownloadL@CShowEngine@@QAEXAAVCShowInfo@@@Z @ 10 NONAME ; void CShowEngine::AddDownloadL(class CShowInfo &)
	?AddFeedL@CFeedEngine@@QAEHABVCFeedInfo@@@Z @ 11 NONAME ; int CFeedEngine::AddFeedL(class CFeedInfo const &)
	?AddObserver@CConnectionEngine@@QAEXPAVMConnectionObserver@@@Z @ 12 NONAME ; void CConnectionEngine::AddObserver(class MConnectionObserver *)
	?AddObserver@CFeedEngine@@QAEXPAVMFeedEngineObserver@@@Z @ 13 NONAME ; void CFeedEngine::AddObserver(class MFeedEngineObserver *)
	?AddObserver@CShowEngine@@QAEXPAVMShowEngineObserver@@@Z @ 14 NONAME ; void CShowEngine::AddObserver(class MShowEngineObserver *)
	?AddSearchResultL@CFeedEngine@@QAEXPAVCFeedInfo@@@Z @ 15 NONAME ; void CFeedEngine::AddSearchResultL(class CFeedInfo *)
	?AddShowL@CShowEngine@@QAEXABVCShowInfo@@@Z @ 16 NONAME ; void CShowEngine::AddShowL(class CShowInfo const &)
	?BaseDir@CSettingsEngine@@QAEAAV?$TBuf@$0BAA@@@XZ @ 17 NONAME ; class TBuf<256> & CSettingsEngine::BaseDir(void)
	?BuildDate@CFeedInfo@@QBE?AVTTime@@XZ @ 18 NONAME ; class TTime CFeedInfo::BuildDate(void) const
	?CancelUpdateAllFeeds@CFeedEngine@@QAEXXZ @ 19 NONAME ; void CFeedEngine::CancelUpdateAllFeeds(void)
	?CleanHtmlL@PodcastUtils@@SAXAAVTDes16@@@Z @ 20 NONAME ; void PodcastUtils::CleanHtmlL(class TDes16 &)
	?ClientState@CFeedEngine@@QAE?AW4TClientState@@XZ @ 21 NONAME ; enum TClientState CFeedEngine::ClientState(void)
	?ConnectionEngine@CPodcastModel@@QAEAAVCConnectionEngine@@XZ @ 22 NONAME ; class CConnectionEngine & CPodcastModel::ConnectionEngine(void)
	?CopyL@CFeedInfo@@QBEPAV1@XZ @ 23 NONAME ; class CFeedInfo * CFeedInfo::CopyL(void) const
	?CustomTitle@CFeedInfo@@QBEHXZ @ 24 NONAME ; int CFeedInfo::CustomTitle(void) const
	?DBGetShowByFileNameL@CShowEngine@@QAEPAVCShowInfo@@V?$TBuf@$0BAA@@@@Z @ 25 NONAME ; class CShowInfo * CShowEngine::DBGetShowByFileNameL(class TBuf<256>)
	?DeleteAllShowsByFeedL@CShowEngine@@QAEXIH@Z @ 26 NONAME ; void CShowEngine::DeleteAllShowsByFeedL(unsigned int, int)
	?DeleteOldShowsByFeedL@CShowEngine@@QAEXI@Z @ 27 NONAME ; void CShowEngine::DeleteOldShowsByFeedL(unsigned int)
	?DeletePlayedShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 28 NONAME ; void CShowEngine::DeletePlayedShowsL(class RPointerArray<class CShowInfo> &)
	?DeleteShowL@CShowEngine@@QAEXIH@Z @ 29 NONAME ; void CShowEngine::DeleteShowL(unsigned int, int)
	?Description@CFeedInfo@@QBEABVTDesC16@@XZ @ 30 NONAME ; class TDesC16 const & CFeedInfo::Description(void) const
	?Description@CShowInfo@@QBEABVTDesC16@@XZ @ 31 NONAME ; class TDesC16 const & CShowInfo::Description(void) const
	?DownloadAutomatically@CSettingsEngine@@QAEHXZ @ 32 NONAME ; int CSettingsEngine::DownloadAutomatically(void)
	?DownloadState@CShowInfo@@QBE?AW4TDownloadState@@XZ @ 33 NONAME ; enum TDownloadState CShowInfo::DownloadState(void) const
	?DownloadSuspended@CSettingsEngine@@QAEHXZ @ 34 NONAME ; int CSettingsEngine::DownloadSuspended(void)
	?EnsureProperPathName@PodcastUtils@@SAXAAV?$TBuf@$0BAA@@@@Z @ 35 NONAME ; void PodcastUtils::EnsureProperPathName(class TBuf<256> &)
	?ExportFeedsL@CFeedEngine@@QAEHAAV?$TBuf@$0BAA@@@@Z @ 36 NONAME ; int CFeedEngine::ExportFeedsL(class TBuf<256> &)
	?FeedEngine@CPodcastModel@@QAEAAVCFeedEngine@@XZ @ 37 NONAME ; class CFeedEngine & CPodcastModel::FeedEngine(void)
	?FeedIcon@CFeedInfo@@QBEPAVCFbsBitmap@@XZ @ 38 NONAME ; class CFbsBitmap * CFeedInfo::FeedIcon(void) const
	?FeedUid@CShowInfo@@QBEIXZ @ 39 NONAME ; unsigned int CShowInfo::FeedUid(void) const
	?FileName@CShowInfo@@QBEABVTDesC16@@XZ @ 40 NONAME ; class TDesC16 const & CShowInfo::FileName(void) const
	?FileNameFromUrl@PodcastUtils@@SAXABVTDesC16@@AAV?$TBuf@$0BAA@@@@Z @ 41 NONAME ; void PodcastUtils::FileNameFromUrl(class TDesC16 const &, class TBuf<256> &)
	?FixProtocolsL@PodcastUtils@@SAXAAVTDes16@@@Z @ 42 NONAME ; void PodcastUtils::FixProtocolsL(class TDes16 &)
	?GetAllShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 43 NONAME ; void CShowEngine::GetAllShowsL(class RPointerArray<class CShowInfo> &)
	?GetFeedInfoByUid@CFeedEngine@@QAEPAVCFeedInfo@@I@Z @ 44 NONAME ; class CFeedInfo * CFeedEngine::GetFeedInfoByUid(unsigned int)
	?GetMimeType@CShowEngine@@QAEXABVTDesC16@@AAVTDes16@@@Z @ 45 NONAME ; void CShowEngine::GetMimeType(class TDesC16 const &, class TDes16 &)
	?GetNewShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 46 NONAME ; void CShowEngine::GetNewShowsL(class RPointerArray<class CShowInfo> &)
	?GetNextShowByTrackL@CShowEngine@@QAEPAVCShowInfo@@PAV2@@Z @ 47 NONAME ; class CShowInfo * CShowEngine::GetNextShowByTrackL(class CShowInfo *)
	?GetNumDownloadingShows@CShowEngine@@QAEHXZ @ 48 NONAME ; int CShowEngine::GetNumDownloadingShows(void)
	?GetSearchResults@CFeedEngine@@QAEABV?$RPointerArray@VCFeedInfo@@@@XZ @ 49 NONAME ; class RPointerArray<class CFeedInfo> const & CFeedEngine::GetSearchResults(void)
	?GetShowByUidL@CShowEngine@@QAEPAVCShowInfo@@I@Z @ 50 NONAME ; class CShowInfo * CShowEngine::GetShowByUidL(unsigned int)
	?GetShowsByFeedL@CPodcastModel@@QAEXI@Z @ 51 NONAME ; void CPodcastModel::GetShowsByFeedL(unsigned int)
	?GetShowsByFeedL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@I@Z @ 52 NONAME ; void CShowEngine::GetShowsByFeedL(class RPointerArray<class CShowInfo> &, unsigned int)
	?GetShowsDownloadedL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 53 NONAME ; void CShowEngine::GetShowsDownloadedL(class RPointerArray<class CShowInfo> &)
	?GetShowsDownloadingL@CPodcastModel@@QAEXXZ @ 54 NONAME ; void CPodcastModel::GetShowsDownloadingL(void)
	?GetShowsDownloadingL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 55 NONAME ; void CShowEngine::GetShowsDownloadingL(class RPointerArray<class CShowInfo> &)
	?GetSortedFeeds@CFeedEngine@@QAEABV?$RPointerArray@VCFeedInfo@@@@XZ @ 56 NONAME ; class RPointerArray<class CFeedInfo> const & CFeedEngine::GetSortedFeeds(void)
	?GetStatsByFeedL@CFeedEngine@@QAEXIAAI0@Z @ 57 NONAME ; void CFeedEngine::GetStatsByFeedL(unsigned int, unsigned int &, unsigned int &)
	?IAPIds@CPodcastModel@@QAEAAV?$RArray@VTPodcastIAPItem@@@@XZ @ 58 NONAME ; class RArray<class TPodcastIAPItem> & CPodcastModel::IAPIds(void)
	?IAPNames@CPodcastModel@@QAEPAVCDesC16ArrayFlat@@XZ @ 59 NONAME ; class CDesC16ArrayFlat * CPodcastModel::IAPNames(void)
	?ImageFileName@CFeedInfo@@QBEABVTDesC16@@XZ @ 60 NONAME ; class TDesC16 const & CFeedInfo::ImageFileName(void) const
	?ImageHandler@CPodcastModel@@QAEAAVCImageHandler@@XZ @ 61 NONAME ; class CImageHandler & CPodcastModel::ImageHandler(void)
	?ImageUrl@CFeedInfo@@QBEABVTDesC16@@XZ @ 62 NONAME ; class TDesC16 const & CFeedInfo::ImageUrl(void) const
	?ImportFeedsL@CFeedEngine@@QAEXABVTDesC16@@@Z @ 63 NONAME ; void CFeedEngine::ImportFeedsL(class TDesC16 const &)
	?IsFirstStartup@CPodcastModel@@QAEHXZ @ 64 NONAME ; int CPodcastModel::IsFirstStartup(void)
	?LastError@CFeedInfo@@QBEHXZ @ 65 NONAME ; int CFeedInfo::LastError(void) const
	?LastError@CShowInfo@@QBEHXZ @ 66 NONAME ; int CShowInfo::LastError(void) const
	?LastUpdated@CFeedInfo@@QBE?AVTTime@@XZ @ 67 NONAME ; class TTime CFeedInfo::LastUpdated(void) const
	?Link@CFeedInfo@@QBEABVTDesC16@@XZ @ 68 NONAME ; class TDesC16 const & CFeedInfo::Link(void) const
	?LoadFileAndScaleL@CImageHandler@@QAEXPAVCFbsBitmap@@ABV?$TBuf@$0BAA@@@ABVTSize@@AAVMImageHandlerCallback@@IH@Z @ 69 NONAME ; void CImageHandler::LoadFileAndScaleL(class CFbsBitmap *, class TBuf<256> const &, class TSize const &, class MImageHandlerCallback &, unsigned int, int)
	?MarkSelectionPlayedL@CPodcastModel@@QAEXXZ @ 70 NONAME ; void CPodcastModel::MarkSelectionPlayedL(void)
	?MetaDataReader@CShowEngine@@QAEAAVCMetaDataReader@@XZ @ 71 NONAME ; class CMetaDataReader & CShowEngine::MetaDataReader(void)
	?NewL@CFeedInfo@@SAPAV1@XZ @ 72 NONAME ; class CFeedInfo * CFeedInfo::NewL(void)
	?NewL@CImageHandler@@SAPAV1@AAVRFs@@AAVCPodcastModel@@@Z @ 73 NONAME ; class CImageHandler * CImageHandler::NewL(class RFs &, class CPodcastModel &)
	?NewL@CPodcastModel@@SAPAV1@XZ @ 74 NONAME ; class CPodcastModel * CPodcastModel::NewL(void)
	?NewL@CShowEngine@@SAPAV1@AAVCPodcastModel@@@Z @ 75 NONAME ; class CShowEngine * CShowEngine::NewL(class CPodcastModel &)
	?NewL@CShowInfo@@SAPAV1@I@Z @ 76 NONAME ; class CShowInfo * CShowInfo::NewL(unsigned int)
	?NewLC@CFeedInfo@@SAPAV1@XZ @ 77 NONAME ; class CFeedInfo * CFeedInfo::NewLC(void)
	?NewLC@CImageHandler@@SAPAV1@AAVRFs@@AAVCPodcastModel@@@Z @ 78 NONAME ; class CImageHandler * CImageHandler::NewLC(class RFs &, class CPodcastModel &)
	?NewLC@CShowInfo@@SAPAV1@I@Z @ 79 NONAME ; class CShowInfo * CShowInfo::NewLC(unsigned int)
	?NotifyShowListUpdatedL@CShowEngine@@QAEXXZ @ 80 NONAME ; void CShowEngine::NotifyShowListUpdatedL(void)
	?OpmlParsingCompleteL@CFeedEngine@@QAEXHI@Z @ 81 NONAME ; void CFeedEngine::OpmlParsingCompleteL(int, unsigned int)
	?PlayPausePodcastL@CPodcastModel@@QAEXPAVCShowInfo@@H@Z @ 82 NONAME ; void CPodcastModel::PlayPausePodcastL(class CShowInfo *, int)
	?PlayState@CShowInfo@@QBE?AW4TPlayState@@XZ @ 83 NONAME ; enum TPlayState CShowInfo::PlayState(void) const
	?PlayTime@CShowInfo@@QBEIXZ @ 84 NONAME ; unsigned int CShowInfo::PlayTime(void) const
	?PlayingPodcast@CPodcastModel@@QAEPAVCShowInfo@@XZ @ 85 NONAME ; class CShowInfo * CPodcastModel::PlayingPodcast(void)
	?Position@CShowInfo@@QBE?AVTTimeIntervalMicroSeconds@@XZ @ 86 NONAME ; class TTimeIntervalMicroSeconds CShowInfo::Position(void) const
	?PubDate@CShowInfo@@QBE?BVTTime@@XZ @ 87 NONAME ; class TTime const CShowInfo::PubDate(void) const
	?RemoveAllDownloadsL@CShowEngine@@QAEXXZ @ 88 NONAME ; void CShowEngine::RemoveAllDownloadsL(void)
	?RemoveAllFormatting@PodcastUtils@@SAXAAVTDes16@@@Z @ 89 NONAME ; void PodcastUtils::RemoveAllFormatting(class TDes16 &)
	?RemoveDownloadL@CShowEngine@@QAEXI@Z @ 90 NONAME ; void CShowEngine::RemoveDownloadL(unsigned int)
	?RemoveFeedL@CFeedEngine@@QAEXI@Z @ 91 NONAME ; void CFeedEngine::RemoveFeedL(unsigned int)
	?RemoveObserver@CFeedEngine@@QAEXPAVMFeedEngineObserver@@@Z @ 92 NONAME ; void CFeedEngine::RemoveObserver(class MFeedEngineObserver *)
	?RemoveObserver@CShowEngine@@QAEXPAVMShowEngineObserver@@@Z @ 93 NONAME ; void CShowEngine::RemoveObserver(class MShowEngineObserver *)
	?ReplaceChar@PodcastUtils@@SAXAAVTDes16@@II@Z @ 94 NONAME ; void PodcastUtils::ReplaceChar(class TDes16 &, unsigned int, unsigned int)
	?ReplaceString@PodcastUtils@@SAXAAVTDes16@@ABVTDesC16@@1@Z @ 95 NONAME ; void PodcastUtils::ReplaceString(class TDes16 &, class TDesC16 const &, class TDesC16 const &)
	?ResumeDownloadsL@CShowEngine@@QAEXXZ @ 96 NONAME ; void CShowEngine::ResumeDownloadsL(void)
	?SNAPIds@CPodcastModel@@QAEAAV?$RArray@VTPodcastIAPItem@@@@XZ @ 97 NONAME ; class RArray<class TPodcastIAPItem> & CPodcastModel::SNAPIds(void)
	?SNAPNames@CPodcastModel@@QAEPAVCDesC16ArrayFlat@@XZ @ 98 NONAME ; class CDesC16ArrayFlat * CPodcastModel::SNAPNames(void)
	?SQLEncode@PodcastUtils@@SAXAAVTDes16@@@Z @ 99 NONAME ; void PodcastUtils::SQLEncode(class TDes16 &)
	?SaveSettingsL@CSettingsEngine@@QAEXXZ @ 100 NONAME ; void CSettingsEngine::SaveSettingsL(void)
	?ScaledBitmap@CImageHandler@@QAEPAVCFbsBitmap@@XZ @ 101 NONAME ; class CFbsBitmap * CImageHandler::ScaledBitmap(void)
	?SearchForFeedL@CFeedEngine@@QAEXAAVTDesC16@@@Z @ 102 NONAME ; void CFeedEngine::SearchForFeedL(class TDesC16 &)
	?SetActiveFeedInfo@CPodcastModel@@QAEXPAVCFeedInfo@@@Z @ 103 NONAME ; void CPodcastModel::SetActiveFeedInfo(class CFeedInfo *)
	?SetBaseDir@CSettingsEngine@@QAEXAAV?$TBuf@$0BAA@@@@Z @ 104 NONAME ; void CSettingsEngine::SetBaseDir(class TBuf<256> &)
	?SetBuildDate@CFeedInfo@@QAEXVTTime@@@Z @ 105 NONAME ; void CFeedInfo::SetBuildDate(class TTime)
	?SetCustomTitle@CFeedInfo@@QAEXXZ @ 106 NONAME ; void CFeedInfo::SetCustomTitle(void)
	?SetDescriptionL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 107 NONAME ; void CFeedInfo::SetDescriptionL(class TDesC16 const &)
	?SetDescriptionL@CShowInfo@@QAEXABVTDesC16@@@Z @ 108 NONAME ; void CShowInfo::SetDescriptionL(class TDesC16 const &)
	?SetDownloadAutomatically@CSettingsEngine@@QAEXH@Z @ 109 NONAME ; void CSettingsEngine::SetDownloadAutomatically(int)
	?SetDownloadState@CShowInfo@@QAEXW4TDownloadState@@@Z @ 110 NONAME ; void CShowInfo::SetDownloadState(enum TDownloadState)
	?SetDownloadSuspended@CSettingsEngine@@QAEXH@Z @ 111 NONAME ; void CSettingsEngine::SetDownloadSuspended(int)
	?SetFeedIcon@CFeedInfo@@QAEXPAVCFbsBitmap@@@Z @ 112 NONAME ; void CFeedInfo::SetFeedIcon(class CFbsBitmap *)
	?SetFeedUid@CShowInfo@@QAEXI@Z @ 113 NONAME ; void CShowInfo::SetFeedUid(unsigned int)
	?SetFileNameL@CShowInfo@@QAEXABVTDesC16@@@Z @ 114 NONAME ; void CShowInfo::SetFileNameL(class TDesC16 const &)
	?SetImageFileNameL@CFeedInfo@@QAEXABVTDesC16@@PAVCPodcastModel@@@Z @ 115 NONAME ; void CFeedInfo::SetImageFileNameL(class TDesC16 const &, class CPodcastModel *)
	?SetImageUrlL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 116 NONAME ; void CFeedInfo::SetImageUrlL(class TDesC16 const &)
	?SetLastError@CFeedInfo@@QAEXH@Z @ 117 NONAME ; void CFeedInfo::SetLastError(int)
	?SetLastError@CShowInfo@@QAEXH@Z @ 118 NONAME ; void CShowInfo::SetLastError(int)
	?SetLastUpdated@CFeedInfo@@QAEXVTTime@@@Z @ 119 NONAME ; void CFeedInfo::SetLastUpdated(class TTime)
	?SetLinkL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 120 NONAME ; void CFeedInfo::SetLinkL(class TDesC16 const &)
	?SetPlayState@CShowInfo@@QAEXW4TPlayState@@@Z @ 121 NONAME ; void CShowInfo::SetPlayState(enum TPlayState)
	?SetPlayTime@CShowInfo@@QAEXI@Z @ 122 NONAME ; void CShowInfo::SetPlayTime(unsigned int)
	?SetPlayingPodcast@CPodcastModel@@QAEXPAVCShowInfo@@@Z @ 123 NONAME ; void CPodcastModel::SetPlayingPodcast(class CShowInfo *)
	?SetPosition@CShowInfo@@QAEXVTTimeIntervalMicroSeconds@@@Z @ 124 NONAME ; void CShowInfo::SetPosition(class TTimeIntervalMicroSeconds)
	?SetPubDate@CShowInfo@@QAEXVTTime@@@Z @ 125 NONAME ; void CShowInfo::SetPubDate(class TTime)
	?SetShowSize@CShowInfo@@QAEXI@Z @ 126 NONAME ; void CShowInfo::SetShowSize(unsigned int)
	?SetShowType@CShowInfo@@QAEXW4TShowType@@@Z @ 127 NONAME ; void CShowInfo::SetShowType(enum TShowType)
	?SetSpecificIAP@CSettingsEngine@@QAEXH@Z @ 128 NONAME ; void CSettingsEngine::SetSpecificIAP(int)
	?SetTitleL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 129 NONAME ; void CFeedInfo::SetTitleL(class TDesC16 const &)
	?SetTitleL@CShowInfo@@QAEXABVTDesC16@@@Z @ 130 NONAME ; void CShowInfo::SetTitleL(class TDesC16 const &)
	?SetTrackNo@CShowInfo@@QAEXI@Z @ 131 NONAME ; void CShowInfo::SetTrackNo(unsigned int)
	?SetUid@CShowInfo@@QAEXI@Z @ 132 NONAME ; void CShowInfo::SetUid(unsigned int)
	?SetUpdateAutomatically@CSettingsEngine@@QAEXW4TAutoUpdateSetting@@@Z @ 133 NONAME ; void CSettingsEngine::SetUpdateAutomatically(enum TAutoUpdateSetting)
	?SetUpdateFeedInterval@CSettingsEngine@@QAEXH@Z @ 134 NONAME ; void CSettingsEngine::SetUpdateFeedInterval(int)
	?SetUpdateFeedTime@CSettingsEngine@@QAEXVTTime@@@Z @ 135 NONAME ; void CSettingsEngine::SetUpdateFeedTime(class TTime)
	?SetUrlL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 136 NONAME ; void CFeedInfo::SetUrlL(class TDesC16 const &)
	?SetUrlL@CShowInfo@@QAEXABVTDesC16@@@Z @ 137 NONAME ; void CShowInfo::SetUrlL(class TDesC16 const &)
	?SettingsEngine@CPodcastModel@@QAEAAVCSettingsEngine@@XZ @ 138 NONAME ; class CSettingsEngine & CPodcastModel::SettingsEngine(void)
	?ShowDownloading@CShowEngine@@QAEPAVCShowInfo@@XZ @ 139 NONAME ; class CShowInfo * CShowEngine::ShowDownloading(void)
	?ShowEngine@CPodcastModel@@QAEAAVCShowEngine@@XZ @ 140 NONAME ; class CShowEngine & CPodcastModel::ShowEngine(void)
	?ShowSize@CShowInfo@@QBEIXZ @ 141 NONAME ; unsigned int CShowInfo::ShowSize(void) const
	?ShowType@CShowInfo@@QBE?AW4TShowType@@XZ @ 142 NONAME ; enum TShowType CShowInfo::ShowType(void) const
	?SpecificIAP@CSettingsEngine@@QAEHXZ @ 143 NONAME ; int CSettingsEngine::SpecificIAP(void)
	?SuspendDownloads@CShowEngine@@QAEXXZ @ 144 NONAME ; void CShowEngine::SuspendDownloads(void)
	?Title@CFeedInfo@@QBEABVTDesC16@@XZ @ 145 NONAME ; class TDesC16 const & CFeedInfo::Title(void) const
	?Title@CShowInfo@@QBEABVTDesC16@@XZ @ 146 NONAME ; class TDesC16 const & CShowInfo::Title(void) const
	?TrackNo@CShowInfo@@QBEIXZ @ 147 NONAME ; unsigned int CShowInfo::TrackNo(void) const
	?Uid@CFeedInfo@@QBEIXZ @ 148 NONAME ; unsigned int CFeedInfo::Uid(void) const
	?Uid@CShowInfo@@QBEIXZ @ 149 NONAME ; unsigned int CShowInfo::Uid(void) const
	?UpdateAllFeedsL@CFeedEngine@@QAEXH@Z @ 150 NONAME ; void CFeedEngine::UpdateAllFeedsL(int)
	?UpdateAutomatically@CSettingsEngine@@QAE?AW4TAutoUpdateSetting@@XZ @ 151 NONAME ; enum TAutoUpdateSetting CSettingsEngine::UpdateAutomatically(void)
	?UpdateFeedInfoL@CFeedEngine@@QAEXPAVCFeedInfo@@@Z @ 152 NONAME ; void CFeedEngine::UpdateFeedInfoL(class CFeedInfo *)
	?UpdateFeedInterval@CSettingsEngine@@QAEHXZ @ 153 NONAME ; int CSettingsEngine::UpdateFeedInterval(void)
	?UpdateFeedL@CFeedEngine@@QAEHI@Z @ 154 NONAME ; int CFeedEngine::UpdateFeedL(unsigned int)
	?UpdateFeedTime@CSettingsEngine@@QAE?AVTTime@@XZ @ 155 NONAME ; class TTime CSettingsEngine::UpdateFeedTime(void)
	?UpdateIAPListL@CPodcastModel@@QAEXXZ @ 156 NONAME ; void CPodcastModel::UpdateIAPListL(void)
	?UpdateSNAPListL@CPodcastModel@@QAEXXZ @ 157 NONAME ; void CPodcastModel::UpdateSNAPListL(void)
	?UpdateShowL@CShowEngine@@QAEXAAVCShowInfo@@@Z @ 158 NONAME ; void CShowEngine::UpdateShowL(class CShowInfo &)
	?Url@CFeedInfo@@QBEABVTDesC16@@XZ @ 159 NONAME ; class TDesC16 const & CFeedInfo::Url(void) const
	?Url@CShowInfo@@QBEABVTDesC16@@XZ @ 160 NONAME ; class TDesC16 const & CShowInfo::Url(void) const
	?XMLEncode@PodcastUtils@@SAXAAVTDes16@@@Z @ 161 NONAME ; void PodcastUtils::XMLEncode(class TDes16 &)
	?DropDB@CPodcastModel@@QAEXXZ @ 162 NONAME ; void CPodcastModel::DropDB(void)

